' ***************************************************************************
' * To use a function in a DLL, VB needs to know how the function is        *
' * declared and in which DLL it can be found                               * 
' *                                                                         *
' * A function declaration look like:                                       *
' *                                                                         *
' * Public Declare Function InitInstrument Lib  "hs3.dll"                   *
' *      ( ByVal wAddress As Integer ) As Integer                           *
' *                                                                         *
' *                                                                         *
' * The above declared function is located in a DLL named hs3.dll           * 
' *                                                                         *
' * To use this file with other DLL's, replace all occurances of "hs3.dll"  *
' * by the proper DLL name:                                                 *
' *                                                                         *
' *   - Handyprobe HP2         "hp2.dll"                                    *
' *   - Handyscope HS2         "hs2.dll"                                    *
' *   - Handyscope HS3         "hs3.dll"                                    *
' *   - Handyscope HS4 (DIFF)  "hs4.dll"                                    *
' *   - TiePieSCOPE HS508      "hs508.dll"                                  *
' *   - TiePieSCOPE HS801      "hs801.dll"                                  *
' *   - TP112                  "tp112.dll"                                  *
' *   - TP208                  "tp208.dll"                                  *
' *   - TP508                  "tp508.dll"                                  *
' *   - TP801 ISA              "tp801.dll"                                  *
' *   - TP801 PCI              "pci801.dll"                                 *
' *   - Multi Channel DLL      "MultiCh.dll"                                *
' *                                                                         *
' *                                                                         *
' ***************************************************************************
'
Attribute VB_Name = "Module1"

'  Return codes = bit values. Non-zero is an error:
Public Const E_NO_ERRORS            = &H0000
Public Const E_NO_HARDWARE          = &H0001
Public Const E_NOT_INITIALIZED      = &H0002
Public Const E_NOT_SUPPORTED        = &H0004
Public Const E_NO_GENERATOR         = &H0008
Public Const E_INVALID_CHANNEL      = &H0010
Public Const E_INVALID_VALUE        = &H0020
Public Const E_I2C_ERROR            = &H0040
Public Const E_I2C_INVALID_ADDRESS  = &H0080
Public Const E_I2C_INVALID_SIZE     = &H0100
Public Const E_I2C_NO_ACKNOWLEDGE   = &H0200

'  Channel constants:
Public Const lCh1                   =  1
Public Const lCh2                   =  2
Public Const lCh3                   =  3
Public Const lCh4                   =  4

'  Measure Mode constants, do NOT use for anything else than G/SetMeasureMode().
'  When measuring more channels, simply add the required constants together : e.g. mmCh1 + mmCh2 to measure both Ch1 and Ch2
Public Const mmCh1                  =  1
Public Const mmCh2                  =  2
Public Const mmCh3                  =  4
Public Const mmCh4                  =  8
Public Const mmCh12                 =  3

'  Coupling constants:
Public Const lctAC                  =  0
Public Const lctDC                  =  1

'  Trigger mode constants:
Public Const ltkRising              =  0 '  Trigger when signal passes level in positive direction
Public Const ltkFalling             =  1 '  Trigger when signal passes level in negative direction
Public Const ltkInWindow            =  2 '  Trigger when signal enters marked window
Public Const ltkOutWindow           =  3 '  Trigger when signal leaves marked window
Public Const ltkTVLine              =  4 '  Trigger at TV line sync pulse
Public Const ltkTVFieldOdd          =  5 '  Trigger at Odd TV field sync pulse
Public Const ltkTVFieldEven         =  6 '  Trigger at Even TV field sync pulse
Public Const ltkNet                 =  7 '  Trigger on peaks/dips in the line net
Public Const ltkNthPulse            =  8 '  Trigger on the nth pulse after start of measuring
Public Const ltkPulseLargerM        =  9 '  Trigger if a pulse is larger than M
Public Const ltkPulseSmallerM       = 10 '  Trigger if a pulse is smaller than M
Public Const ltkGlitch              = 11 '  Trigger when the change between two samples is larger than x

'  Trigger source constants for G/SetTriggerSource.
'  It is recommended to use the new routines GetTriggerSources, G/SetTriggerSourceOR and G/SetTriggerSourceAND,
'  with the TS_ constants instead.
Public Const ltsCh1                 =  0 '  Trigger on Ch1
Public Const ltsCh2                 =  1 '  Trigger on Ch2
Public Const ltsCh3                 =  2 '  Trigger on Ch3
Public Const ltsCh4                 =  3 '  Trigger on Ch4
Public Const ltsExternal            =  4 '  Trigger on digital external trigger input
Public Const ltsAnalogExt           =  5 '  Trigger on analog external trigger input
Public Const ltsAnd                 =  6 '  Trigger on Ch1 AND Ch2
Public Const ltsOr                  =  7 '  Trigger on Ch1 OR  Ch2
Public Const ltsXor                 =  8 '  Trigger on Ch1 XOR Ch2
Public Const ltsNoTrig              =  9 '  Do not wait for trigger, measure immediately
Public Const ltsNeverTrig           = 10 '  not used
Public Const ltsPxiExt              = 11 '  Trigger on external PXI trigger inputs
Public Const ltsGenStart            = 12 '  Trigger on Generator Start Signal
Public Const ltsGenStop             = 13 '  Trigger on Generator Stop Signal
Public Const ltsGenNew              = 14 '  Trigger on Generator New Period
Public Const ltsUnknown             = 15 '  not used

'  Trigger source constants for GetTriggerSources, G/SetTriggerSourceOR and G/SetTriggerSourceAND:
Public Const TS_CH1                 = &H0000000000000001 '  2^0
Public Const TS_CH2                 = &H0000000000000002 '  2^1
Public Const TS_CH3                 = &H0000000000000004 '  2^2
Public Const TS_CH4                 = &H0000000000000008 '  ...
Public Const TS_CH5                 = &H0000000000000010
Public Const TS_CH6                 = &H0000000000000020
Public Const TS_CH7                 = &H0000000000000040
Public Const TS_CH8                 = &H0000000000000080
Public Const TS_CHANNELS            = &H00000000FFFFFFFF '  32 channel trigger sources

Public Const TS_EXT                 = &H8000000000000000 '  external digital trigger
Public Const TS_EXTANALOG           = &H4000000000000000 '  external analog trigger
Public Const TS_EXTPXI              = &H2000000000000000 '  external PXI trigger
Public Const TS_GENSTART            = &H1000000000000000 '  trigger when internal function generator starts
Public Const TS_GENNEW              = &H0800000000000000 '  trigger when internal function generator starts a new period
Public Const TS_GENSTOP             = &H0400000000000000 '  trigger when internal function generator stops
Public Const TS_OTHERSOURCES        = &HFFFFFFFF00000000 '  32 bits reserved for other trigger sources

'  Transfer mode constants:
Public Const ltmBlock               =  0
Public Const ltmStream              =  1

'  Instrument Configuration constants:
Public Const licHS3Norm             =  0
Public Const licHS3256K             =  1
Public Const licHS3512K             =  2

'  === Function Generator constants ===

'  FuncGen Modes:
Public Const lfmDDS                 =  1
Public Const lfmLinear              =  2

'  Signal types
Public Const lstSine                =  0
Public Const lstTriangle            =  1
Public Const lstSquare              =  2
Public Const lstDC                  =  3
Public Const lstNoise               =  4
Public Const lstArbitrary           =  5


'  Open / Close the instrument:
Public Declare Function InitInstrument  Lib "MultiCh.dll" ( ByVal wInstrumentCount As Integer ) As Integer
Public Declare Function ExitInstrument  Lib "MultiCh.dll" (  ) As Integer
 
'  Get information about the instrument:
Public Declare Function GetCalibrationDate  Lib "MultiCh.dll" ( ByRef dwDate As Long ) As Integer
Public Declare Function GetSerialNumber  Lib "MultiCh.dll" ( ByRef dwSerialNumber As Long ) As Integer
Public Declare Function GetAvailableSensitivities  Lib "MultiCh.dll" ( ByRef dSensitivities As Double ) As Integer
Public Declare Function GetAvailableResolutions  Lib "MultiCh.dll" ( ByRef dResolutions As Double ) As Integer
Public Declare Function GetNrChannels  Lib "MultiCh.dll" ( ByRef wValue As Integer ) As Integer
Public Declare Function GetMaxSampleFrequencyF  Lib "MultiCh.dll" (  ) As Double
Public Declare Function GetMaxRecordLength  Lib "MultiCh.dll" (  ) As Long
Public Declare Function GetDCLevelStatus  Lib "MultiCh.dll" (  ) As Long
 
'  Measurement routines:
Public Declare Function ADC_Start  Lib "MultiCh.dll" (  ) As Integer
Public Declare Function ADC_Running  Lib "MultiCh.dll" (  ) As Integer
Public Declare Function ADC_Abort  Lib "MultiCh.dll" (  ) As Integer
Public Declare Function ADC_ForceTrig  Lib "MultiCh.dll" (  ) As Integer
Public Declare Function ADC_Triggered  Lib "MultiCh.dll" (  ) As Integer
Public Declare Function ADC_Ready  Lib "MultiCh.dll" (  ) As Integer
 
'  Retrieve the measured data:
Public Declare Function ADC_GetDataCh  Lib "MultiCh.dll" ( ByVal wCh As Integer , ByRef wChData As Integer ) As Integer
Public Declare Function ADC_GetDataVoltCh  Lib "MultiCh.dll" ( ByVal wCh As Integer , ByRef dChData As Double ) As Integer
Public Declare Function GetDigitalInputValues  Lib "MultiCh.dll" ( ByRef wValues As Integer ) As Integer
Public Declare Function GetOneDigitalValue  Lib "MultiCh.dll" ( ByVal dwIndex As Long , ByRef wValue As Integer ) As Integer
 
'  Control the input resolution in bits:
Public Declare Function SetResolution  Lib "MultiCh.dll" ( ByVal byValue As Byte ) As Integer
Public Declare Function GetResolution  Lib "MultiCh.dll" ( ByRef byValue As Byte ) As Integer
 
'  Control the instrument configuration:
Public Declare Function SetInstrumentConfig  Lib "MultiCh.dll" ( ByVal wMode As Integer ) As Integer
 
'  Control which channels are measured:
Public Declare Function GetMeasureMode  Lib "MultiCh.dll" ( ByRef byMode As Byte ) As Integer
Public Declare Function SetMeasureMode  Lib "MultiCh.dll" ( ByVal byMode As Byte ) As Integer
Public Declare Function GetChEnabled  Lib "MultiCh.dll" ( ByVal wCh As Integer , ByRef byEnabled As Byte ) As Integer
Public Declare Function SetChEnabled  Lib "MultiCh.dll" ( ByVal wCh As Integer , ByVal byEnabled As Byte ) As Integer
 
'  Control the time base:
Public Declare Function GetRecordLength  Lib "MultiCh.dll" (  ) As Long
Public Declare Function SetRecordLength  Lib "MultiCh.dll" ( ByVal dwRecordLength As Long ) As Integer
Public Declare Function GetPostSamples  Lib "MultiCh.dll" (  ) As Long
Public Declare Function SetPostSamples  Lib "MultiCh.dll" ( ByVal dwPostSampleCount As Long ) As Integer
Public Declare Function GetSampleFrequencyF  Lib "MultiCh.dll" (  ) As Double
Public Declare Function SetSampleFrequencyF  Lib "MultiCh.dll" ( ByRef dFreq As Double ) As Integer
Public Declare Function GetExternalClock  Lib "MultiCh.dll" ( ByRef wMode As Integer ) As Integer
Public Declare Function SetExternalClock  Lib "MultiCh.dll" ( ByVal wMode As Integer ) As Integer
 
'  Control the analog input channels:
Public Declare Function GetSensitivity  Lib "MultiCh.dll" ( ByVal byCh As Byte , ByRef dSensitivity As Double ) As Integer
Public Declare Function SetSensitivity  Lib "MultiCh.dll" ( ByVal byCh As Byte , ByRef dSensitivity As Double ) As Integer
Public Declare Function GetAutoRanging  Lib "MultiCh.dll" ( ByVal byCh As Byte , ByRef byMode As Byte ) As Integer
Public Declare Function SetAutoRanging  Lib "MultiCh.dll" ( ByVal byCh As Byte , ByVal byMode As Byte ) As Integer
Public Declare Function GetCoupling  Lib "MultiCh.dll" ( ByVal byCh As Byte , ByRef byMode As Byte ) As Integer
Public Declare Function SetCoupling  Lib "MultiCh.dll" ( ByVal byCh As Byte , ByVal byMode As Byte ) As Integer
Public Declare Function GetDcLevel  Lib "MultiCh.dll" ( ByVal byCh As Byte , ByRef dDcLevel As Double ) As Integer
Public Declare Function SetDcLevel  Lib "MultiCh.dll" ( ByVal byCh As Byte , ByVal dDcLevel As Double ) As Integer
 
'  Control the trigger system:
Public Declare Function GetTriggerTimeOut  Lib "MultiCh.dll" (  ) As Long
Public Declare Function SetTriggerTimeOut  Lib "MultiCh.dll" ( ByVal dwTimeout As Long ) As Integer
Public Declare Function GetTriggerSource  Lib "MultiCh.dll" ( ByRef byTrigSource As Byte ) As Integer
Public Declare Function SetTriggerSource  Lib "MultiCh.dll" ( ByVal byTrigSource As Byte ) As Integer
'  For more control, use these routines for trigger source, instead of the ones above:
Public Declare Function GetTriggerSources  Lib "MultiCh.dll" ( ByRef nTrigMask As Int64 ) As Integer
Public Declare Function GetTriggerSourceOR  Lib "MultiCh.dll" ( ByRef nTrigMask As Int64 ) As Integer
Public Declare Function SetTriggerSourceOR  Lib "MultiCh.dll" ( ByVal nTrigMask As Int64 ) As Integer
Public Declare Function GetTriggerSourceAND  Lib "MultiCh.dll" ( ByRef nTrigMask As Int64 ) As Integer
Public Declare Function SetTriggerSourceAND  Lib "MultiCh.dll" ( ByVal nTrigMask As Int64 ) As Integer
Public Declare Function GetTriggerMode  Lib "MultiCh.dll" ( ByRef byMode As Byte ) As Integer
Public Declare Function SetTriggerMode  Lib "MultiCh.dll" ( ByVal byMode As Byte ) As Integer
Public Declare Function GetTriggerModeCh  Lib "MultiCh.dll" ( ByVal byCh As Byte , ByRef byMode As Byte ) As Integer
Public Declare Function SetTriggerModeCh  Lib "MultiCh.dll" ( ByVal byCh As Byte , ByVal byMode As Byte ) As Integer
Public Declare Function GetTriggerLevel  Lib "MultiCh.dll" ( ByVal byCh As Byte , ByRef dLevel As Double ) As Integer
Public Declare Function SetTriggerLevel  Lib "MultiCh.dll" ( ByVal byCh As Byte , ByVal dLevel As Double ) As Integer
Public Declare Function GetTriggerHys  Lib "MultiCh.dll" ( ByVal byCh As Byte , ByRef dHysteresis As Double ) As Integer
Public Declare Function SetTriggerHys  Lib "MultiCh.dll" ( ByVal byCh As Byte , ByVal dHysteresis As Double ) As Integer
Public Declare Function GetPXITriggerEnables  Lib "MultiCh.dll" ( ByRef byEnables As Byte ) As Integer
Public Declare Function SetPXITriggerEnables  Lib "MultiCh.dll" ( ByVal byEnables As Byte ) As Integer
Public Declare Function GetPXITriggerSlopes  Lib "MultiCh.dll" ( ByRef bySlopes As Byte ) As Integer
Public Declare Function SetPXITriggerSlopes  Lib "MultiCh.dll" ( ByVal bySlopes As Byte ) As Integer
 
'  Control the digital outputs:
Public Declare Function SetDigitalOutputs  Lib "MultiCh.dll" ( ByVal byValue As Byte ) As Integer
Public Declare Function GetDigitalOutputs  Lib "MultiCh.dll" ( ByRef byValue As Byte ) As Integer
 
'  Square Wave Generator:
Public Declare Function GetSquareWaveGenStatus  Lib "MultiCh.dll" (  ) As Integer
Public Declare Function GetSquareWaveGenFrequency  Lib "MultiCh.dll" (  ) As Long
Public Declare Function SetSquareWaveGenFrequency  Lib "MultiCh.dll" ( ByRef dwFreq As Long ) As Integer
 
'  Get information about the function generator:
Public Declare Function GetFunctionGenStatus  Lib "MultiCh.dll" (  ) As Integer
Public Declare Function GetFuncGenMaxAmplitude  Lib "MultiCh.dll" ( ByRef dMaxAmplitude As Double ) As Integer
 
'  Control the Arbitrary Waveform Generator:
Public Declare Function GetFuncGenOutputOn  Lib "MultiCh.dll" ( ByRef wValue As Integer ) As Integer
Public Declare Function SetFuncGenOutputOn  Lib "MultiCh.dll" ( ByVal wValue As Integer ) As Integer
Public Declare Function GetFuncGenEnable  Lib "MultiCh.dll" ( ByRef wValue As Integer ) As Integer
Public Declare Function SetFuncGenEnable  Lib "MultiCh.dll" ( ByVal wValue As Integer ) As Integer
Public Declare Function GetFuncGenSignalType  Lib "MultiCh.dll" ( ByRef wValue As Integer ) As Integer
Public Declare Function SetFuncGenSignalType  Lib "MultiCh.dll" ( ByVal wValue As Integer ) As Integer
Public Declare Function GetFuncGenMode  Lib "MultiCh.dll" ( ByRef dwMode As Long ) As Integer
Public Declare Function SetFuncGenMode  Lib "MultiCh.dll" ( ByVal dwMode As Long ) As Integer
Public Declare Function GetFuncGenAmplitude  Lib "MultiCh.dll" ( ByRef dValue As Double ) As Integer
Public Declare Function SetFuncGenAmplitude  Lib "MultiCh.dll" ( ByVal dValue As Double ) As Integer
Public Declare Function GetFuncGenDCOffset  Lib "MultiCh.dll" ( ByRef dValue As Double ) As Integer
Public Declare Function SetFuncGenDCOffset  Lib "MultiCh.dll" ( ByVal dValue As Double ) As Integer
Public Declare Function GetFuncGenSymmetry  Lib "MultiCh.dll" ( ByRef dValue As Double ) As Integer
Public Declare Function SetFuncGenSymmetry  Lib "MultiCh.dll" ( ByVal dValue As Double ) As Integer
Public Declare Function GetFuncGenFrequency  Lib "MultiCh.dll" ( ByRef dValue As Double ) As Integer
Public Declare Function SetFuncGenFrequency  Lib "MultiCh.dll" ( ByRef dValue As Double ) As Integer
Public Declare Function SetFuncGenTrigSource  Lib "MultiCh.dll" ( ByVal byTrigSource As Byte ) As Integer
Public Declare Function GetFuncGenTrigSource  Lib "MultiCh.dll" ( ByRef byTrigSource As Byte ) As Integer
Public Declare Function FillFuncGenMemory  Lib "MultiCh.dll" ( ByVal dwSampleCount As Long , ByRef FuncGenData As Integer ) As Integer
Public Declare Function FuncGenBurst  Lib "MultiCh.dll" ( ByVal wNrPeriods As Integer ) As Integer
 
'  Control multiple Arbitrary Waveform Generators:
Public Declare Function GetFunctionGeneratorCount  Lib "MultiCh.dll" (  ) As Integer
 
Public Declare Function GetFuncGenOutputOnCh  Lib "MultiCh.dll" ( ByVal wCh As Integer , ByRef wValue As Integer ) As Integer
Public Declare Function SetFuncGenOutputOnCh  Lib "MultiCh.dll" ( ByVal wCh As Integer , ByVal wValue As Integer ) As Integer
Public Declare Function GetFuncGenEnableCh  Lib "MultiCh.dll" ( ByVal wCh As Integer , ByRef wValue As Integer ) As Integer
Public Declare Function SetFuncGenEnableCh  Lib "MultiCh.dll" ( ByVal wCh As Integer , ByVal wValue As Integer ) As Integer
Public Declare Function GetFuncGenSignalTypeCh  Lib "MultiCh.dll" ( ByVal wCh As Integer , ByRef wValue As Integer ) As Integer
Public Declare Function SetFuncGenSignalTypeCh  Lib "MultiCh.dll" ( ByVal wCh As Integer , ByVal wValue As Integer ) As Integer
Public Declare Function GetFuncGenModeCh  Lib "MultiCh.dll" ( ByVal wCh As Integer , ByRef dwMode As Long ) As Integer
Public Declare Function SetFuncGenModeCh  Lib "MultiCh.dll" ( ByVal wCh As Integer , ByVal dwMode As Long ) As Integer
Public Declare Function GetFuncGenMaxAmplitudeCh  Lib "MultiCh.dll" ( ByVal wCh As Integer , ByRef dValue As Double ) As Integer
Public Declare Function GetFuncGenAmplitudeCh  Lib "MultiCh.dll" ( ByVal wCh As Integer , ByRef dValue As Double ) As Integer
Public Declare Function SetFuncGenAmplitudeCh  Lib "MultiCh.dll" ( ByVal wCh As Integer , ByVal dValue As Double ) As Integer
Public Declare Function GetFuncGenDCOffsetCh  Lib "MultiCh.dll" ( ByVal wCh As Integer , ByRef dValue As Double ) As Integer
Public Declare Function SetFuncGenDCOffsetCh  Lib "MultiCh.dll" ( ByVal wCh As Integer , ByVal dValue As Double ) As Integer
Public Declare Function GetFuncGenSymmetryCh  Lib "MultiCh.dll" ( ByVal wCh As Integer , ByRef dValue As Double ) As Integer
Public Declare Function SetFuncGenSymmetryCh  Lib "MultiCh.dll" ( ByVal wCh As Integer , ByVal dValue As Double ) As Integer
Public Declare Function GetFuncGenFrequencyCh  Lib "MultiCh.dll" ( ByVal wCh As Integer , ByRef dValue As Double ) As Integer
Public Declare Function SetFuncGenFrequencyCh  Lib "MultiCh.dll" ( ByVal wCh As Integer , ByRef dValue As Double ) As Integer
Public Declare Function GetFuncGenTrigSourceCh  Lib "MultiCh.dll" ( ByVal wCh As Integer , ByRef byTrigSource As Byte ) As Integer
Public Declare Function SetFuncGenTrigSourceCh  Lib "MultiCh.dll" ( ByVal wCh As Integer , ByVal byTrigSource As Byte ) As Integer
Public Declare Function FillFuncGenMemoryCh  Lib "MultiCh.dll" ( ByVal wCh As Integer , ByVal dwSampleCount As Long , ByRef FuncGenData As Integer ) As Integer
Public Declare Function FuncGenBurstCh  Lib "MultiCh.dll" ( ByVal wCh As Integer , ByVal wNrPeriods As Integer ) As Integer
 
'  Ohm measurements ( not available by default ):
Public Declare Function SetupOhmMeasurements  Lib "MultiCh.dll" ( ByVal wMode As Integer ) As Integer
Public Declare Function GetOhmValues  Lib "MultiCh.dll" ( ByRef dValue1 As Double , ByRef dValue2 As Double ) As Integer
 
'  I2C routines:
Public Declare Function I2CWrite  Lib "MultiCh.dll" ( ByVal dwAddress As Long , ByVal pBuf As pointer , ByVal dwSize As Long ) As Integer
Public Declare Function I2CWriteNoStop  Lib "MultiCh.dll" ( ByVal dwAddress As Long , ByVal pBuf As pointer , ByVal dwSize As Long ) As Integer
Public Declare Function I2CRead  Lib "MultiCh.dll" ( ByVal dwAddress As Long , ByVal pBuf As pointer , ByVal dwSize As Long ) As Integer
Public Declare Function I2CReadNoStop  Lib "MultiCh.dll" ( ByVal dwAddress As Long , ByVal pBuf As pointer , ByVal dwSize As Long ) As Integer
Public Declare Function I2CGetSpeed  Lib "MultiCh.dll" ( ByRef dwSpeed As Long ) As Integer
Public Declare Function I2CSetSpeed  Lib "MultiCh.dll" ( ByRef dwSpeed As Long ) As Integer
 
'  I2C routines for acces to I2C-buses other than that of the first instrument:
Public Declare Function I2CWriteCh  Lib "MultiCh.dll" ( ByVal wCh As Integer , ByVal dwAddress As Long , ByVal pBuf As pointer , ByVal dwSize As Long ) As Integer
Public Declare Function I2CWriteNoStopCh  Lib "MultiCh.dll" ( ByVal wCh As Integer , ByVal dwAddress As Long , ByVal pBuf As pointer , ByVal dwSize As Long ) As Integer
Public Declare Function I2CReadCh  Lib "MultiCh.dll" ( ByVal wCh As Integer , ByVal dwAddress As Long , ByVal pBuf As pointer , ByVal dwSize As Long ) As Integer
Public Declare Function I2CReadNoStopCh  Lib "MultiCh.dll" ( ByVal wCh As Integer , ByVal dwAddress As Long , ByVal pBuf As pointer , ByVal dwSize As Long ) As Integer
Public Declare Function I2CGetSpeedCh  Lib "MultiCh.dll" ( ByVal wCh As Integer , ByRef dwSpeed As Long ) As Integer
Public Declare Function I2CSetSpeedCh  Lib "MultiCh.dll" ( ByVal wCh As Integer , ByRef dwSpeed As Long ) As Integer
 
'  Obsolete routines, use is deprecated:
Public Declare Function StartMeasurement  Lib "MultiCh.dll" (  ) As Integer
 
Public Declare Function GetMeasurement  Lib "MultiCh.dll" ( ByRef dCh1 As Double , ByRef dCh2 As Double ) As Integer
Public Declare Function GetMeasurementCh  Lib "MultiCh.dll" ( ByVal wCh As Integer , ByRef dChData As Double ) As Integer
Public Declare Function GetMeasurementRaw  Lib "MultiCh.dll" ( ByRef wCh1 As Integer , ByRef wCh2 As Integer ) As Integer
Public Declare Function GetMeasurementRawCh  Lib "MultiCh.dll" ( ByVal wCh As Integer , ByRef wChData As Integer ) As Integer
Public Declare Function GetOneMeasurement  Lib "MultiCh.dll" ( ByVal dwIndex As Long , ByRef dCh1 As Double , ByRef dCh2 As Double ) As Integer
Public Declare Function GetOneMeasurementCh  Lib "MultiCh.dll" ( ByVal wCh As Integer , ByVal dwIndex As Long , ByRef dChData As Double ) As Integer
Public Declare Function GetOneMeasurementRaw  Lib "MultiCh.dll" ( ByVal dwIndex As Long , ByRef wCh1 As Integer , ByRef wCh2 As Integer ) As Integer
Public Declare Function GetOneMeasurementRawCh  Lib "MultiCh.dll" ( ByVal wCh As Integer , ByVal dwIndex As Long , ByRef wChData As Integer ) As Integer
Public Declare Function ADC_GetData  Lib "MultiCh.dll" ( ByRef wCh1 As Integer , ByRef wCh2 As Integer ) As Integer
Public Declare Function ADC_GetDataVolt  Lib "MultiCh.dll" ( ByRef dCh1 As Double , ByRef dCh2 As Double ) As Integer
 
Public Declare Function GetMaxSampleFrequency  Lib "MultiCh.dll" (  ) As Long
Public Declare Function GetSampleFrequency  Lib "MultiCh.dll" (  ) As Long
Public Declare Function SetSampleFrequency  Lib "MultiCh.dll" ( ByRef dwFreq As Long ) As Integer
 
'  Streaming measurements:
Public Declare Function SetDataReadyCallback  Lib "MultiCh.dll" ( ByVal pAddress As Long ) As Integer
Public Declare Function SetDataReadyEvent  Lib "MultiCh.dll" ( ByVal hEvent As THandle ) As Integer
Public Declare Function SetTransferMode  Lib "MultiCh.dll" ( ByVal dwMode As Long ) As Integer
Public Declare Function GetTransferMode  Lib "MultiCh.dll" ( ByRef dwMode As Long ) As Integer

